import processing.core.*; import java.util.Random; import java.applet.*; import java.awt.*; import java.awt.image.*; import java.awt.event.*; import java.io.*; import java.net.*; import java.text.*; import java.util.*; import java.util.zip.*; import javax.sound.midi.*; import javax.sound.midi.spi.*; import javax.sound.sampled.*; import javax.sound.sampled.spi.*; import java.util.regex.*; import javax.xml.parsers.*; import javax.xml.transform.*; import javax.xml.transform.dom.*; import javax.xml.transform.sax.*; import javax.xml.transform.stream.*; import org.xml.sax.*; import org.xml.sax.ext.*; import org.xml.sax.helpers.*; public class PollockPaint extends PApplet {/**
 * PollockPaint 
 * by Holden Link.
 * 
 *  Paint program for Jackson Pollock fans.
 * 
 * 
 * Click anywhere on the canvas area to draw. Move the mouse slowly for best results.
 * Press the up or down arrows on the keyboard to change the size of your "brush."
 * Click on any of the colors on your palette (at the bottom) to change to that color.
 * Press the "R" key to reset the canvas.
 * 
 * Code used from the following Processing example files:
 * Buttons, MousePress, Words, Keyboard
 * 
 **/


PFont pollockFont;
int userColor, highlight, buttonColor;
Random generator = new Random();
int userSize = 10;
boolean locked = false;
RectButton redButton, blueButton, greenButton, yellowButton,
orangeButton, purpleButton, blackButton, whiteButton, userButton;
int otherColor = color(32,194,0);


public void setup() 
{
  size(800,600);
  background(255);
  frameRate(15);
  smooth();
  pollockFont = loadFont("LucidaHandwriting-Italic-20.vlw");
  textFont(pollockFont, 18);

  highlight = color(0,0,0);
  userColor = color(213,0,0);

  // Define and create Red Button
  buttonColor = color(213,0,0);
  redButton = new RectButton(20, 545, 50, buttonColor, highlight);

  // Define and create Green Button
  buttonColor = color(32,194,0);
  greenButton = new RectButton(80, 545, 50, buttonColor, highlight);

  // Define and create Blue Button
  buttonColor = color(0,0,215);
  blueButton = new RectButton(140, 545, 50, buttonColor, highlight);

  // Define and create Yellow Button
  buttonColor = color(247,238,0);
  yellowButton = new RectButton(200, 545, 50, buttonColor, highlight);

  // Define and create Orange Button
  buttonColor = color(247,174,0);
  orangeButton = new RectButton(260, 545, 50, buttonColor, highlight);

  // Define and create Purple Button
  buttonColor = color(157,0,180);
  purpleButton = new RectButton(320, 545, 50, buttonColor, highlight);

  // Define and create White Button
  buttonColor = color(255,255,255);
  whiteButton = new RectButton(380, 545, 50, buttonColor, highlight);

  // Define and create Black Button
  buttonColor = color(0,0,0);
  blackButton = new RectButton(440, 545, 50, buttonColor, highlight);

  // Define and create User Button
  buttonColor = color(50,50,50);
  userButton = new RectButton(730, 545, 50, buttonColor, highlight);

}

public void draw() 
{
  update(mouseX, mouseY);
  fill(255);
  rect(0, 540, 800, 60);
  fill(0);
  text("SIZE:", 550, 580);
  text(str(userSize), 620, 580);
  redButton.display();
  blueButton.display();
  greenButton.display();
  purpleButton.display();
  orangeButton.display();
  yellowButton.display();
  whiteButton.display();
  blackButton.display();
  userButton.display();

  if(keyPressed) {
    if ((key == 'r') || (key == 'R')){
      fill(255);
      stroke(255);
      setup();
    }
    if (key == CODED) {
      if (keyCode == UP)
        {
          userSize++;
        }
        if (keyCode == DOWN) {
          userSize--;
        }
    }    
  }

  if(mousePressed) {
    int x = generator.nextInt(userSize) + 1;
    int y = generator.nextInt(userSize) + 1;
    int colorSkew1 = generator.nextInt(20) + 1;
    int colorSkew2 = generator.nextInt(20) + 1;
    int colorSkew3 = generator.nextInt(20) + 1;
    stroke(userColor+color(colorSkew1,colorSkew2,colorSkew3));
    fill(userColor+color(colorSkew1,colorSkew2,colorSkew3));
    if((userColor == color(255,255,255)) || (userColor == color(247,174,0)) || (userColor == color(247,238,0))){
      stroke(userColor);
      fill(userColor);
    }
    ellipse(mouseX,mouseY, x, y);

  }


}

public void update(int x, int y)
{
  if(locked == false) {
    redButton.update();
    blueButton.update();
    greenButton.update();
    yellowButton.update();
    blackButton.update();
    whiteButton.update();
    orangeButton.update();
    purpleButton.update();
    userButton.update();


  } 
  else {
    locked = false;
  }

  if(mousePressed) {
    if(redButton.pressed()) {
      userColor = redButton.basecolor;
    } 
    else if(blueButton.pressed()) {
      userColor = blueButton.basecolor;
    } 
    else if(greenButton.pressed()) {
      userColor = greenButton.basecolor;
    } 
    else if(orangeButton.pressed()) {
      userColor = orangeButton.basecolor;
    } 
    else if(blackButton.pressed()) {
      userColor = blackButton.basecolor;
    } 
    else if(purpleButton.pressed()) {
      userColor = purpleButton.basecolor;
    } 
    else if(yellowButton.pressed()) {
      userColor = yellowButton.basecolor;
    } 
    else if(whiteButton.pressed()) {
      userColor = whiteButton.basecolor;
    } 



  }
  userButton.basecolor = userColor;
}


class Button
{
  int x, y;
  int size;
  int basecolor, highlightcolor;
  int currentcolor;
  boolean over = false;
  boolean pressed = false;   

  public void update() 
  {
    if(over()) {
      currentcolor = highlightcolor;
    } 
    else {
      currentcolor = basecolor;
    }
  }

  public boolean pressed() 
  {
    if(over) {
      locked = true;
      return true;
    } 
    else {
      locked = false;
      return false;
    }    
  }

  public boolean over() 
  { 
    return true; 
  }

  public boolean overRect(int x, int y, int width, int height) 
  {
    if (mouseX >= x && mouseX <= x+width && 
      mouseY >= y && mouseY <= y+height) {
      return true;
    } 
    else {
      return false;
    }
  }
}

class RectButton extends Button
{
  RectButton(int ix, int iy, int isize, int icolor, int ihighlight) 
  {
    x = ix;
    y = iy;
    size = isize;
    basecolor = icolor;
    highlightcolor = ihighlight;
    currentcolor = basecolor;
  }

  public boolean over() 
  {
    if( overRect(x, y, size, size) ) {
      over = true;
      return true;
    } 
    else {
      over = false;
      return false;
    }
  }

  public void display() 
  {
    stroke(highlightcolor);
    fill(basecolor);
    rect(x, y, size, size);

  }
}

  static public void main(String args[]) {     PApplet.main(new String[] { "PollockPaint" });  }}